@@ -2,7 +2,7 @@ import json
 from collections import OrderedDict
 from functools import wraps
 
-from ..app_context import AppContext
+from ..context import AppContext
 from ..http import HttpRequest, HttpServerError
 from ..http import HttpResponse, HttpBadRequest, JsonResponse
 from ..middleware import MiddlewareManager
@@ -98,7 +98,7 @@ def _invoke_with_route(request: HttpRequest, meta: RouteMeta, context: AppContex
     if result is not None:
         return mgr.handle_response(_wrap_http_response(mgr, result))
 
-    # 调用路由处理函数
+    # 调用路由函数
     arg_len = len(func_args)
     if arg_len == 0:
         return mgr.handle_response(_wrap_http_response(mgr, func()))
@@ -142,10 +142,10 @@ def _process_json_params(request: HttpRequest, context: AppContext):
 
 
 def _get_parameter_str(args: OrderedDict):
-    return '\n\t\t'.join([str(args[arg]) for arg in args])
+    return ', '.join(filter(lambda n: n[0] != '_', [str(args[arg]) for arg in args]))
 
 
-def _get_value(data: dict, name: str, arg_spec: ArgumentSpecification, backup=None):
+def _get_value(data: dict, name: str, arg_spec: ArgumentSpecification, backup1, backup2):
     """
 
     :param data:
@@ -161,12 +161,19 @@ def _get_value(data: dict, name: str, arg_spec: ArgumentSpecification, backup=No
     if alias is not None and alias in data:
         return False, data[alias]
 
-    if isinstance(backup, dict):
-        if name in backup:
-            return False, backup[name]
+    if isinstance(backup1, dict):
+        if name in backup1:
+            return False, backup1[name]
 
-        if alias is not None and alias in backup:
-            return False, backup[alias]
+        if alias is not None and alias in backup1:
+            return False, backup1[alias]
+
+    if isinstance(backup2, dict):
+        if name in backup2:
+            return False, backup2[name]
+
+        if alias is not None and alias in backup2:
+            return False, backup2[alias]
 
     # 使用默认值
     if arg_spec.has_default:
@@ -188,9 +195,17 @@ def _get_actual_args(request: HttpRequest, func, args: OrderedDict, context: App
     # noinspection PyUnresolvedReferences
     arg_source = request.GET if method in ['delete', 'get'] else request.POST
 
+    # 声明的注入参数集合
+    injection_args = []
+
     for arg_name in args.keys():
         arg_spec = args.get(arg_name)
 
+        if arg_spec.is_injected:
+            injection_args.append(arg_name)
+            used_args.append(arg_name)
+            continue
+
         # 如果是可变参数：如: **kwargs
         # 设置标记，以在后面进行填充
         if arg_spec.is_variable:
@@ -209,16 +224,18 @@ def _get_actual_args(request: HttpRequest, func, args: OrderedDict, context: App
             continue
 
         # noinspection PyUnresolvedReferences
-        use_default, arg_value = _get_value(arg_source, arg_name, arg_spec, request.BODY)
+        use_default, arg_value = _get_value(arg_source, arg_name, arg_spec, request.BODY, request.FILES)
 
         # 未找到参数
         if use_default is None:
-            msg = '%s\n\tMissing required argument "%s":\n\t\t%s' % (
+            msg = '%s\n\tMissing required argument "%s", Parameters: (%s)' % (
                 get_func_info(func),
                 arg_name,
                 _get_parameter_str(args)
             )
             context.logger.warning(msg)
+            if not context.DEBUG:
+                msg = 'Missing required argument'
             return HttpBadRequest(msg)
 
         # 使用默认值
@@ -278,19 +295,34 @@ def _get_actual_args(request: HttpRequest, func, args: OrderedDict, context: App
 
                 # 类型一致，直接使用
                 if isinstance(arg_value, arg_spec.annotation):
-                    actual_args[arg_name] = arg_value
+                    # 如果原始声明是 tuple 类型，那么把 list 转换成 tuple
+                    # 虽然在发起请求的时候并不能指定为 tuple，但还是想兼容一下
+                    actual_args[arg_name] = tuple(arg_value) if arg_spec.is_tuple else arg_value
                     used_args.append(arg_name)
                     continue
             actual_args[arg_name] = arg_spec.annotation(arg_value)
             used_args.append(arg_name)
         except Exception:
-            msg = 'Argument type of "%s" mismatch, expect type "%s" but got "%s", signature: (%s)' \
+            msg = 'Argument type of "%s" mismatch, expect type "%s" but got "%s", Parameters: (%s)' \
                   % (arg_name, arg_spec.annotation.__name__, type(arg_value).__name__, _get_parameter_str(args))
             context.logger.warning(msg)
+            if not context.DEBUG:
+                msg = 'Argument type mismatch'
             return HttpBadRequest(msg)
 
-    if not has_variable_args:
-        return actual_args
+    # 填充注入参数
+    for arg_name in injection_args:
+        # 注入名称不包含前缀 _
+        # 所以要 [1:]
+        injection_name = arg_name[1:]
+        if injection_name in request.injections:
+            actual_args[arg_name] = request.injections[injection_name]
+        elif injection_name in context.injections:
+            actual_args[arg_name] = context.injections[injection_name]
+        else:
+            msg = 'Injection name "%s" not found' % injection_name
+            context.logger.warning(msg)
+            return HttpServerError(msg) if context.DEBUG else HttpServerError()
 
     # 填充可变参数
     variable_args = {}
@@ -307,9 +339,30 @@ def _get_actual_args(request: HttpRequest, func, args: OrderedDict, context: App
             # noinspection PyUnresolvedReferences
             variable_args[item] = request.BODY[item]
 
-    actual_args.update(variable_args)
+    variable_arg_keys = variable_args.keys()
 
-    return actual_args
+    # 没有可变参数
+    if not variable_arg_keys:
+        return actual_args
+
+    # 有可变参数，并且指定了 kwargs
+    if has_variable_args:
+        actual_args.update(variable_args)
+        return actual_args
+
+    # 有可变参数，并且未指定 kwargs
+    # 未启用严格模式
+    if context.strict_mode is not True:
+        return actual_args
+
+    # 启用了严格模式
+    # 返回 400 响应
+    msg = 'Unknown argument(s) found: "%s", Parameters: (%s)' \
+          % (','.join(variable_arg_keys), _get_parameter_str(args))
+    context.logger.warning(msg)
+    if not context.DEBUG:
+        msg = 'Unknown argument(s)'
+    return HttpBadRequest(msg)
 
 
 def _wrap_http_response(mgr, data):
