@@ -2,7 +2,7 @@ import os
 from types import FunctionType
 
 from .route_resolver import RouteResolver
-from ..app_context import AppContext
+from ..context import AppContext
 from ..http import HttpNotFound, HttpServerError, HttpResponse, JsonResponse
 from ..http.request import HttpRequest
 from ..util.func_util import FunctionDescription
@@ -17,7 +17,7 @@ class Router:
         :type:Dict[str, Optional[FunctionDescription]]
         """
         # 开发模式的模块缓存，用于API列表
-        self.modules_cache = {}
+        self.routes_cache = {}
         # 线上模式时，使用固定路由
         self.production_routes = {}
         # API列表页面缓存
@@ -31,13 +31,15 @@ class Router:
         :param request:
         :return:
         """
-        if not self.context.DEBUG:
+        if not self.context.enable_api_page:
             self.context.logger.info(
-                'API list is disabled in production, use "App(..., debug_mode=True, ...)" to enable it.')
+                'API list is disabled, '
+                'use "App(..., enable_api_page=True, ...)" to enable it.')
             return HttpResponse(status=404)
 
-        if not self.api_list_html_cache or True:
-            with open(os.path.join(os.path.dirname(__file__), '../assets_for_dev/templates/api_list.html'),
+        if not self.api_list_html_cache or not self.context.dev_options['api_page_cache']:
+            with open(os.path.join(os.path.dirname(__file__),
+                                   '../assets_for_dev/templates/api_list.html'),
                       encoding='utf-8') as fp:
                 lines = fp.readlines()
                 self.api_list_html_cache = ''.join(lines)
@@ -46,11 +48,9 @@ class Router:
         if request.method != 'POST':
             return HttpResponse(self.api_list_html_cache, content_type='text/html')
 
-        if not self.modules_cache:
+        if not self.routes_cache or not self.context.dev_options['api_page_cache']:
             routes = self.context.collector.collect(self.context.routes_map)
 
-            modules = {}
-
             if 'api_list_addition' in self.context.dev_options:
                 addition_func = self.context.dev_options['api_list_addition']
             else:
@@ -59,15 +59,11 @@ class Router:
                 # 附加信息
                 if addition_func is not None:
                     route['addition_info'] = addition_func(route)
+                # 移除 kwargs，以避免额外数据带来的数据传输消耗
+                if 'kwargs' in route:
+                    del route['kwargs']
 
-                module = route['module']
-
-                if module in modules:
-                    modules[module].append(route)
-                else:
-                    modules[module] = [route]
-
-            self.modules_cache = modules
+            self.routes_cache = routes
 
         from restfx import __meta__
         return JsonResponse({
@@ -77,14 +73,14 @@ class Router:
             },
             'app_name': self.context.dev_options['app_name'],
             'expanded': self.context.dev_options['api_list_expanded'],
-            'apis': self.modules_cache,
+            'routes': self.routes_cache,
         }, encoder=FunctionDescription.JSONEncoder)
 
     def dispatch(self, request: HttpRequest, entry):
         """
         路由分发入口
         :param request: 请求
-        :param entry: 入口文件，包名使用 . 符号分隔
+        :param entry: 入口地址
         :return:
         """
         if self.intercepter is not None:
@@ -92,10 +88,10 @@ class Router:
             entry = self.intercepter(request, entry)
 
         if not self.context.DEBUG:
-            return self.route_for_production(request, entry)
+            return self.route_for_production(request, '/' + entry)
 
         resolver = RouteResolver(self.context,
-                                 self.modules_cache,
+                                 self.routes_cache,
                                  self.entry_cache,
                                  request.method, entry)
 
@@ -120,4 +116,4 @@ class Router:
             return func(request, args)
         except Exception as e:
             self.context.logger.error(e)
-            return HttpServerError('%s: %s' % (repr(e)))
+            return HttpServerError(repr(e))
