@@ -21,6 +21,9 @@ class ArgumentSpecification:
         """
         self.name = name
         self.index = index
+        # 是否是注入参数
+        # 注入参数名称以 _ 开头
+        self.is_injected = name[0] == '_'
         # 是否是可变参数
         self.is_variable = False
         # 是否有类型声明
@@ -29,28 +32,36 @@ class ArgumentSpecification:
         self.has_default = False
         # 类型声明
         self.annotation = None
+        # 类型是否是 tuple
+        # 因为在处理类型时，会将 tuple 当作 list 对待
+        self.is_tuple = False
         # 默认值
         self.default = None
         # 注释
         self.comment = None
-        # 别名，当路由处理函数中声明的是 abc_def 时，自动处理为 abcDef
+        # 别名，当路由函数中声明的是 abc_def_xyz 时，自动处理为 abcDefXyz
+        self.alias = None
+
+        if self.is_injected:
+            return
+
+        if '_' not in self.name:
+            return
+
         # 同时会移除所有的 _ 符号
         self.alias = re.sub('_+(?P<ch>.?)', ArgumentSpecification._get_parameter_alias, name)
-        # 如果与原名称相同，那么就设置为 None 表示无别名
-        if self.alias == name:
-            self.alias = None
 
     @property
     def annotation_name(self):
-        return self.annotation.__name__ if self.has_annotation else 'any'
+        return self.annotation.__name__ if self.has_annotation else None
 
     def __str__(self):
-        arg_type = self.annotation.__name__ if self.has_annotation else 'any'
-
         name = self.name
 
         name = name if self.alias is None else '%s/%s' % (name, self.alias)
 
+        arg_type = self.annotation.__name__ if self.has_annotation else None
+
         if self.has_default:
             default_value = "'%s'" % self.default if isinstance(self.default, str) else self.default
             return '%s: %s=%s' % (name, arg_type, default_value)
@@ -64,6 +75,7 @@ class ArgumentSpecification:
             return {
                 'name': o.name,
                 'index': o.index,
+                'is_injected': o.is_injected,
                 'is_variable': o.is_variable,
                 'has_annotation': o.has_annotation,
                 'has_default': o.has_default,
@@ -119,6 +131,7 @@ class FunctionDescription:
         for p in parameters.keys():
             parameter = parameters.get(p)
             spec = ArgumentSpecification(p, index)
+
             spec.is_variable = parameter.kind == parameter.VAR_KEYWORD
 
             if p in documatation:
@@ -164,6 +177,10 @@ class FunctionDescription:
                 spec.annotation = annotation
                 spec.has_annotation = True
 
+            # 如果声明的是元组，那么当成 list 来传
+            if spec.has_annotation and spec.annotation == tuple:
+                spec.annotation = list
+                spec.is_tuple = True
             args[p] = spec
 
         return args
